Take

Struct Take 

pub struct Take<R> { /* private fields */ }
Reader for the AsyncReadExt::take() method.

Implementations

Source

impl<R> Take<R>

pub fn limit(&self) -> u64

Returns the number of bytes before this adapter will return EOF.

Note that EOF may be reached sooner if the underlying reader is shorter than the limit.

Examples
use futures_lite::io::{AsyncReadExt, Cursor};

let reader = Cursor::new("hello");

let reader = reader.take(3);
assert_eq!(reader.limit(), 3);
pub fn set_limit(&mut self, limit: u64)

Puts a limit on the number of bytes.

Changing the limit is equivalent to creating a new adapter with AsyncReadExt::take().

Examples
use futures_lite::io::{AsyncReadExt, Cursor};

let reader = Cursor::new("hello");

let mut reader = reader.take(10);
assert_eq!(reader.limit(), 10);

reader.set_limit(3);
assert_eq!(reader.limit(), 3);
pub fn get_ref(&self) -> &R

Gets a reference to the underlying reader.

Examples
use futures_lite::io::{AsyncReadExt, Cursor};

let reader = Cursor::new("hello");

let reader = reader.take(3);
let r = reader.get_ref();
pub fn get_mut(&mut self) -> &mut R

Gets a mutable reference to the underlying reader.

Examples
use futures_lite::io::{AsyncReadExt, Cursor};

let reader = Cursor::new("hello");

let mut reader = reader.take(3);
let r = reader.get_mut();
pub fn into_inner(self) -> R

Unwraps the adapter, returning the underlying reader.

Examples
use futures_lite::io::{AsyncReadExt, Cursor};

let reader = Cursor::new("hello");

let reader = reader.take(3);
let reader = reader.into_inner();