pub struct Take<R> { /* private fields */ }Expand description
Reader for the AsyncReadExt::take() method.
Implementations
Sourceimpl<R> Take<R>
impl<R> Take<R>
Sourcepub fn limit(&self) -> u64
pub fn limit(&self) -> u64
Returns the number of bytes before this adapter will return EOF.
Note that EOF may be reached sooner if the underlying reader is shorter than the limit.
Examples
use futures_lite::io::{AsyncReadExt, Cursor};
let reader = Cursor::new("hello");
let reader = reader.take(3);
assert_eq!(reader.limit(), 3);Sourcepub fn set_limit(&mut self, limit: u64)
pub fn set_limit(&mut self, limit: u64)
Puts a limit on the number of bytes.
Changing the limit is equivalent to creating a new adapter with AsyncReadExt::take().
Examples
use futures_lite::io::{AsyncReadExt, Cursor};
let reader = Cursor::new("hello");
let mut reader = reader.take(10);
assert_eq!(reader.limit(), 10);
reader.set_limit(3);
assert_eq!(reader.limit(), 3);Sourcepub fn get_ref(&self) -> &R
pub fn get_ref(&self) -> &R
Gets a reference to the underlying reader.
Examples
use futures_lite::io::{AsyncReadExt, Cursor};
let reader = Cursor::new("hello");
let reader = reader.take(3);
let r = reader.get_ref();Sourcepub fn get_mut(&mut self) -> &mut R
pub fn get_mut(&mut self) -> &mut R
Gets a mutable reference to the underlying reader.
Examples
use futures_lite::io::{AsyncReadExt, Cursor};
let reader = Cursor::new("hello");
let mut reader = reader.take(3);
let r = reader.get_mut();Sourcepub fn into_inner(self) -> R
pub fn into_inner(self) -> R
Unwraps the adapter, returning the underlying reader.
Examples
use futures_lite::io::{AsyncReadExt, Cursor};
let reader = Cursor::new("hello");
let reader = reader.take(3);
let reader = reader.into_inner();Trait Implementations
Sourceimpl<R> AsyncBufRead for Take<R>where
R: AsyncBufRead,
impl<R> AsyncBufRead for Take<R>where
R: AsyncBufRead,
Sourceimpl<R> AsyncRead for Take<R>where
R: AsyncRead,
impl<R> AsyncRead for Take<R>where
R: AsyncRead,
impl<'__pin, R> Unpin for Take<R>where
<PinnedFieldsOfHelperStruct<__Origin<'__pin, R>> as PinnedFieldsOfHelperTrait>::Actual: Unpin,